'use strict';

var _from = require('babel-runtime/core-js/array/from');

var _from2 = _interopRequireDefault(_from);

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _map = require('babel-runtime/core-js/map');

var _map2 = _interopRequireDefault(_map);

Object.defineProperty(exports, "__esModule", {
  value: true
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// key = name used by react_on_rails
// value = { name, route }
var _routes = new _map2.default();

exports.default = {
  /**
   * @param routes { route1: route1, route2: route2, etc. }
   */

  register: function register(routes) {
    (0, _keys2.default)(routes).forEach(function (name) {
      if (_routes.has(name)) {
        console.warn('Called register for route that is already registered', name);
      }

      var route = routes[name];
      if (!route) {
        throw new Error('Called register with null route named ' + name);
      }

      _routes.set(name, {
        name: name,
        route: route
      });
    });
  },

  /**
   * @param name
   * @returns { name, route, generatorFunction }
   */
  get: function get(name) {
    if (_routes.has(name)) {
      return _routes.get(name);
    } else {
      var keys = (0, _from2.default)(_routes.keys()).join(', ');
      throw new Error('Could not find route registered with name ' + name + '. Registered route names include [ ' + keys + ' ]. Maybe you forgot to register the route?');
    }
  },

  /**
   * Get a Map containing all registered routes. Useful for debugging.
   * @returns Map where key is the route name and values are the
   * { name, route, generatorFunction}
   */
  routes: function routes() {
    return _routes;
  }
};